@@ -1,14 +1,20 @@
 <?php
 
-
 /**
-  * SquirrelMail Login Multilogin
-  * Copyright (C) 2003, 2004 Paul Lesneiwski <pdontthink@angrynerds.com>
-  * This program is licensed under GPL. See COPYING for details
+  * SquirrelMail Multilogin Plugin
+  * Copyright (c) 2003-2005 Paul Lesneiwski <paul@openguild.net>
+  * Licensed under the GNU GPL. For full terms see the file COPYING.
+  *
+  * @package plugins
+  * @subpackage multilogin
   *
   */
 
 
+/**
+  * Register this plugin with SquirrelMail
+  *
+  */
 function squirrelmail_plugin_init_multilogin() {
 
    global $squirrelmail_plugin_hooks;
@@ -26,14 +32,19 @@ function squirrelmail_plugin_init_multilogin() {
 
 
 
+/** @ignore */
 if (!defined('SM_PATH'))
    define('SM_PATH', '../');
 
 
 
+/**
+  * Returns version info about this plugin
+  *
+  */
 function multilogin_version()
 {
-   return '2.3';
+   return '2.3.2-1.2';
 }
 
 
@@ -42,11 +53,11 @@ function multilogin_version()
   * store the user's IMAP server in the session
   *
   */
-function multilogin_registerIMAPServer()
+function multilogin_registerIMAPServer($args='')
 {
 
    include_once(SM_PATH . 'plugins/multilogin/functions.php');
-   multilogin_registerIMAPServer_do();
+   multilogin_registerIMAPServer_do($args);
 
 }
 
@@ -69,11 +80,11 @@ function multilogin_insertIMAPSelection()
   * present IMAP server selection pull-down
   *
   */
-function multilogin_sqoverride_config()
+function multilogin_sqoverride_config($args='')
 {
 
    include_once(SM_PATH . 'plugins/multilogin/functions.php');
-   multilogin_sqoverride_config_do();
+   multilogin_sqoverride_config_do($args);
 
 }
 
